# InlineResponse2002

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**parameters** | [**InlineResponse2001Parameters**](InlineResponse2001Parameters.md) |  |
**software_environments** | [**list[InlineResponse2002SoftwareEnvironments]**](InlineResponse2002SoftwareEnvironments.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
